@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2010-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2010-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,7 +13,8 @@
 
 class Transport;
 
-namespace KIdentityManagement {
+namespace KIdentityManagement
+{
 class Identity;
 }
 
